@@ -60,7 +60,8 @@ class Auth:
 
     def attempt_api_key(self, attempts=1):
         s = f'. Attempt {attempts} of 3' if attempts > 1 else ' from https://hub.ultralytics.com/settings/api-keys'
-        api_key = getpass.getpass(f"{PREFIX}Enter API key{s}:")
+        print(PREFIX, end='')
+        api_key = getpass.getpass(f"Enter API key{s}: ")
         self.validate_api_key(api_key)
         if not (self.api_key):
             attempts += 1
@@ -69,7 +70,7 @@ class Auth:
             if attempts <= 3:
                 return self.attempt_api_key(attempts)
             else:
-                print(f"{PREFIX}Failed to authenticate. Exiting...")
+                print(f"{PREFIX}Failed to authenticate.")
                 return False
         else:
             return True
