@@ -1,11 +1,14 @@
-from .hub_logger import HUBLogger
-from .yolov5_wrapper import YOLOv5Wrapper as YOLOv5
-import requests
-import json
-from .config import HUB_API_ROOT
-
 import sys
 
+import requests
+
+from .config import HUB_API_ROOT
+from .hub_logger import HUBLogger
+from .utils.general import colorstr
+from .yolov5_wrapper import YOLOv5Wrapper as YOLOv5
+
+PREFIX = colorstr('Ultralytics HUB: ')
+
 
 class Trainer:
     def __init__(self, model_id, auth):
@@ -14,11 +17,11 @@ class Trainer:
 
         self._connectCallbacks()
 
-    def _get_model_by_id():
+    def _get_model_by_id(self):
         # return a specific model
         return
 
-    def _get_next_model():
+    def _get_next_model(self):
         # return next model in queue
         return
 
@@ -35,20 +38,18 @@ class Trainer:
             res = r.json()
 
             if res["data"] == None:
-                print("\nERROR: Unable to fetch model")
-                sys.exit()  # Cannot train without model
+                print(f"\n{PREFIX}ERROR: Unable to fetch model")
+                exit()  # Cannot train without model
             elif not res["data"]:
-                print("\nYou have no models pending training.")
-                sys.exit()  # Cannot train without model
+                print(f"\n{PREFIX}You have no models pending training.")
+                exit()  # Cannot train without model
             else:
                 self.model_id = res["data"][
                     "id"]  # Append id as it may be fetched from queue and unknown
                 return res["data"]
         except requests.exceptions.ConnectionError:
-            print(
-                '\nERROR: The HUB server is not online. Please try again later.'
-            )
-            sys.exit(141)
+            print(f'\n{PREFIX}ERROR: The HUB server is not online. Please try again later.')
+            sys.exit(141)  # TODO: keep this 141 sys exit error code?
 
     def _connectCallbacks(self):
         callback_handler = YOLOv5.newCallbackHandler()
